#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef HAVE_DIRENT_H
#undef HAVE_SYS_TIME_H
#undef HAVE_SYS_SELECT_H
#undef HAVE_GNU_REGEXP
#undef WITH_REGEX
#undef HAVE_GTKTEXT_PATCH
#undef USE_FORK_CODE
#undef HAVE_GUILE
